@@ -75,6 +75,7 @@ import com.openexchange.file.storage.FileStorageFolderAccess;
 import com.openexchange.file.storage.NameBuilder;
 import com.openexchange.file.storage.Quota;
 import com.openexchange.file.storage.Quota.Type;
+import com.openexchange.file.storage.UserCreatedFileStorageFolderAccess;
 import com.openexchange.file.storage.googledrive.access.GoogleDriveOAuthAccess;
 import com.openexchange.file.storage.googledrive.osgi.Services;
 import com.openexchange.server.ServiceExceptionCode;
@@ -85,11 +86,7 @@ import com.openexchange.session.Session;
  *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
-public final class GoogleDriveFolderAccess extends AbstractGoogleDriveAccess implements FileStorageFolderAccess, FileStorageAutoRenameFoldersAccess {
-
-    private static final String QUERY_STRING_DIRECTORIES_ONLY = GoogleDriveConstants.QUERY_STRING_DIRECTORIES_ONLY;
-
-    // ---------------------------------------------------------------------------------------------------------------------- //
+public final class GoogleDriveFolderAccess extends AbstractGoogleDriveAccess implements FileStorageFolderAccess, FileStorageAutoRenameFoldersAccess, UserCreatedFileStorageFolderAccess {
 
     private final int userId;
     private final String accountDisplayName;
@@ -406,7 +403,6 @@ public final class GoogleDriveFolderAccess extends AbstractGoogleDriveAccess imp
                 List<ChildReference> existingFolders = list.execute().getItems();
                 if (!existingFolders.isEmpty()) {
                     // Check if there is already such a folder
-                    int retries = 0;
                     boolean alreadySuchAFolder;
                     do {
                         alreadySuchAFolder = false;
